//
// Frdric Boulanger
// Suplec - Dpartement Informatique
// 3 rue Joliot-Curie
// 91192 Gif-sur-Yvette cedex, France
//
// frederic.boulanger@supelec.fr
//
/**
 * Une forme d'onde est une manire de gnrer un signal d'une 
 * frquence donne chantillonn  une certaine frquence.
 */
abstract class FormeOnde {
  /** Frquence fondamentale du signal. */
  protected final double f0_;
  /** Frquence d'chantillonnage. */
  protected final double fe_;

  /** 
   * Construit une forme d'onde de frquence <code>f0</code> 
   * avec une frquence d'chantillonnage <code>fe</code>.
   * @param f0 est la frquence fondamentale du signal
   * @param fe est la frquence d'chantillonnage
   */
  public FormeOnde(double f0, double fe) {
    f0_ = f0;
    fe_ = fe;
  }

  /**
   * Calcule un chantillon du signal.
   * @param i est l'indice de l'chantillon dont la date est i/fe_
   * @return la valeur de l'chantillon, normalise entre -1.0 et 1.0
   */
  public abstract double echantillon(int i);

  /**
   * Rend la frquence du signal.
   */
  public double frequence() {
    return f0_;
  }

  /**
   * Rend la frquence d'chantillonnage du signal.
   */
  public double frequenceEch() {
    return fe_;
  }
}
